==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fLxor.h <==
// class soot.coffi.Instruction_Lxor

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b4f3e689b4083430 soot_coffi_Instruction__5fLxor
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fLxor_H_
#define _JC_soot_coffi_Instruction__5fLxor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLxor$sub_refs	_jc_soot_coffi_Instruction__5fLxor$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$sub_nonrefs	_jc_soot_coffi_Instruction__5fLxor$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$refs	_jc_soot_coffi_Instruction__5fLxor$refs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$nonrefs	_jc_soot_coffi_Instruction__5fLxor$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$object	_jc_soot_coffi_Instruction__5fLxor$object;

typedef const struct _jc_soot_coffi_Instruction__5fLxor$vmethods	_jc_soot_coffi_Instruction__5fLxor$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLxor$vtable	_jc_soot_coffi_Instruction__5fLxor$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLxor$vtype	_jc_soot_coffi_Instruction__5fLxor$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLxor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLxor$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLxor$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLxor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fLxor$vmethods	soot_coffi_Instruction__5fLxor;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLxor$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLxor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLxor$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLxor$refs {
    _jc_soot_coffi_Instruction__5fLxor$sub_refs	soot_coffi_Instruction__5fLxor;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLxor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLxor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fLxor$sub_nonrefs	soot_coffi_Instruction__5fLxor;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLxor$object {
	_jc_soot_coffi_Instruction__5fLxor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLxor$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLxor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLxor$vtype _jc_soot_coffi_Instruction__5fLxor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLxor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLxor$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLxor_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fLxor.h <==
// class soot.coffi.Instruction_Lxor

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b4f3e689b4083430 soot_coffi_Instruction__5fLxor
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fLxor_H_
#define _JC_soot_coffi_Instruction__5fLxor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fLxor$sub_refs	_jc_soot_coffi_Instruction__5fLxor$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$sub_nonrefs	_jc_soot_coffi_Instruction__5fLxor$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$refs	_jc_soot_coffi_Instruction__5fLxor$refs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$nonrefs	_jc_soot_coffi_Instruction__5fLxor$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fLxor$object	_jc_soot_coffi_Instruction__5fLxor$object;

typedef const struct _jc_soot_coffi_Instruction__5fLxor$vmethods	_jc_soot_coffi_Instruction__5fLxor$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fLxor$vtable	_jc_soot_coffi_Instruction__5fLxor$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fLxor$vtype	_jc_soot_coffi_Instruction__5fLxor$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fLxor$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fLxor$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fLxor$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fLxor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fLxor$vmethods	soot_coffi_Instruction__5fLxor;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fLxor$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fLxor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLxor$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLxor$refs {
    _jc_soot_coffi_Instruction__5fLxor$sub_refs	soot_coffi_Instruction__5fLxor;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fLxor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fLxor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fLxor$sub_nonrefs	soot_coffi_Instruction__5fLxor;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fLxor$object {
	_jc_soot_coffi_Instruction__5fLxor$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fLxor$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fLxor$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fLxor$vtype _jc_soot_coffi_Instruction__5fLxor$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fLxor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fLxor$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fLxor_H_ */
